@@ -2,7 +2,7 @@
  * network.c: virNetwork methods
  *
  * Copyright (C) 2007,2010 Red Hat Inc.
- * Copyright (C) 2013 Chris Lalancette <clalancette@gmail.com>
+ * Copyright (C) 2013-2016 Chris Lalancette <clalancette@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,7 +48,7 @@ VALUE ruby_libvirt_network_new(virNetworkPtr n, VALUE conn)
  * call-seq:
  *   net.undefine -> nil
  *
- * Call virNetworkUndefine[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkUndefine]
+ * Call virNetworkUndefine[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkUndefine]
  * to undefine this network.
  */
 static VALUE libvirt_network_undefine(VALUE n)
@@ -62,7 +62,7 @@ static VALUE libvirt_network_undefine(VALUE n)
  * call-seq:
  *   net.create -> nil
  *
- * Call virNetworkCreate[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkCreate]
+ * Call virNetworkCreate[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkCreate]
  * to start this network.
  */
 static VALUE libvirt_network_create(VALUE n)
@@ -77,7 +77,7 @@ static VALUE libvirt_network_create(VALUE n)
  * call-seq:
  *   net.update -> nil
  *
- * Call virNetworkUpdate[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkUpdate]
+ * Call virNetworkUpdate[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkUpdate]
  * to update this network.
  */
 static VALUE libvirt_network_update(VALUE n, VALUE command, VALUE section,
@@ -95,7 +95,7 @@ static VALUE libvirt_network_update(VALUE n, VALUE command, VALUE section,
  * call-seq:
  *   net.destroy -> nil
  *
- * Call virNetworkDestroy[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkDestroy]
+ * Call virNetworkDestroy[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkDestroy]
  * to shutdown this network.
  */
 static VALUE libvirt_network_destroy(VALUE n)
@@ -107,9 +107,9 @@ static VALUE libvirt_network_destroy(VALUE n)
 
 /*
  * call-seq:
- *   net.name -> string
+ *   net.name -> String
  *
- * Call virNetworkGetName[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkGetName]
+ * Call virNetworkGetName[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetName]
  * to retrieve the name of this network.
  */
 static VALUE libvirt_network_name(VALUE n)
@@ -121,9 +121,9 @@ static VALUE libvirt_network_name(VALUE n)
 
 /*
  * call-seq:
- *   net.uuid -> string
+ *   net.uuid -> String
  *
- * Call virNetworkGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkGetUUIDString]
+ * Call virNetworkGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetUUIDString]
  * to retrieve the UUID of this network.
  */
 static VALUE libvirt_network_uuid(VALUE n)
@@ -134,9 +134,9 @@ static VALUE libvirt_network_uuid(VALUE n)
 
 /*
  * call-seq:
- *   net.xml_desc(flags=0) -> string
+ *   net.xml_desc(flags=0) -> String
  *
- * Call virNetworkGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkGetXMLDesc]
+ * Call virNetworkGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetXMLDesc]
  * to retrieve the XML for this network.
  */
 static VALUE libvirt_network_xml_desc(int argc, VALUE *argv, VALUE n)
@@ -153,9 +153,9 @@ static VALUE libvirt_network_xml_desc(int argc, VALUE *argv, VALUE n)
 
 /*
  * call-seq:
- *   net.bridge_name -> string
+ *   net.bridge_name -> String
  *
- * Call virNetworkGetBridgeName[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkGetBridgeName]
+ * Call virNetworkGetBridgeName[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetBridgeName]
  * to retrieve the bridge name for this network.
  */
 static VALUE libvirt_network_bridge_name(VALUE n)
@@ -169,7 +169,7 @@ static VALUE libvirt_network_bridge_name(VALUE n)
  * call-seq:
  *   net.autostart? -> [true|false]
  *
- * Call virNetworkGetAutostart[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkGetAutostart]
+ * Call virNetworkGetAutostart[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetAutostart]
  * to determine if this network will be autostarted when libvirtd starts.
  */
 static VALUE libvirt_network_autostart(VALUE n)
@@ -187,7 +187,7 @@ static VALUE libvirt_network_autostart(VALUE n)
  * call-seq:
  *   net.autostart = [true|false]
  *
- * Call virNetworkSetAutostart[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkSetAutostart]
+ * Call virNetworkSetAutostart[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkSetAutostart]
  * to set this network to be autostarted when libvirtd starts.
  */
 static VALUE libvirt_network_autostart_equal(VALUE n, VALUE autostart)
@@ -206,7 +206,7 @@ static VALUE libvirt_network_autostart_equal(VALUE n, VALUE autostart)
  * call-seq:
  *   net.free -> nil
  *
- * Call virNetworkFree[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkFree]
+ * Call virNetworkFree[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkFree]
  * to free this network.  The object will no longer be valid after this call.
  */
 static VALUE libvirt_network_free(VALUE n)
@@ -219,7 +219,7 @@ static VALUE libvirt_network_free(VALUE n)
  * call-seq:
  *   net.active? -> [true|false]
  *
- * Call virNetworkIsActive[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkIsActive]
+ * Call virNetworkIsActive[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkIsActive]
  * to determine if this network is currently active.
  */
 static VALUE libvirt_network_active_p(VALUE n)
@@ -235,7 +235,7 @@ static VALUE libvirt_network_active_p(VALUE n)
  * call-seq:
  *   net.persistent? -> [true|false]
  *
- * Call virNetworkIsPersistent[http://www.libvirt.org/html/libvirt-libvirt.html#virNetworkIsPersistent]
+ * Call virNetworkIsPersistent[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkIsPersistent]
  * to determine if this network is persistent.
  */
 static VALUE libvirt_network_persistent_p(VALUE n)
@@ -246,6 +246,92 @@ static VALUE libvirt_network_persistent_p(VALUE n)
 }
 #endif
 
+#if HAVE_VIRNETWORKGETDHCPLEASES
+struct leases_arg {
+    virNetworkDHCPLeasePtr *leases;
+    int nleases;
+};
+
+static VALUE leases_wrap(VALUE arg)
+{
+    struct leases_arg *e = (struct leases_arg *)arg;
+    VALUE result, hash;
+    virNetworkDHCPLeasePtr lease;
+    int i;
+
+    result = rb_ary_new2(e->nleases);
+
+    for (i = 0; i < e->nleases; i++) {
+        lease = e->leases[i];
+
+        hash = rb_hash_new();
+        rb_hash_aset(hash, rb_str_new2("iface"), rb_str_new2(lease->iface));
+        rb_hash_aset(hash, rb_str_new2("expirytime"),
+                     LL2NUM(lease->expirytime));
+        rb_hash_aset(hash, rb_str_new2("type"), INT2NUM(lease->type));
+        if (lease->mac) {
+            rb_hash_aset(hash, rb_str_new2("mac"), rb_str_new2(lease->mac));
+        }
+        if (lease->iaid) {
+            rb_hash_aset(hash, rb_str_new2("iaid"), rb_str_new2(lease->iaid));
+        }
+        rb_hash_aset(hash, rb_str_new2("ipaddr"), rb_str_new2(lease->ipaddr));
+        rb_hash_aset(hash, rb_str_new2("prefix"), UINT2NUM(lease->prefix));
+        if (lease->hostname) {
+            rb_hash_aset(hash, rb_str_new2("hostname"),
+                         rb_str_new2(lease->hostname));
+        }
+        if (lease->clientid) {
+            rb_hash_aset(hash, rb_str_new2("clientid"),
+                         rb_str_new2(lease->clientid));
+        }
+
+        rb_ary_store(result, i, hash);
+    }
+
+    return result;
+}
+
+/*
+ * call-seq:
+ *   net.dhcp_leases(mac=nil, flags=0) -> Hash
+ *
+ * Call virNetworkGetDHCPLeases[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetDHCPLeases]
+ * to retrieve the leases for this network.
+ */
+static VALUE libvirt_network_get_dhcp_leases(int argc, VALUE *argv, VALUE n)
+{
+    VALUE mac, flags, result;
+    int nleases, i = 0, exception = 0;
+    virNetworkDHCPLeasePtr *leases = NULL;
+    struct leases_arg args;
+
+    rb_scan_args(argc, argv, "02", &mac, &flags);
+
+    nleases = virNetworkGetDHCPLeases(network_get(n),
+                                      ruby_libvirt_get_cstring_or_null(mac),
+                                      &leases,
+                                      ruby_libvirt_value_to_uint(flags));
+    ruby_libvirt_raise_error_if(nleases < 0, e_Error, "virNetworkGetDHCPLeases",
+                                ruby_libvirt_connect_get(n));
+
+    args.leases = leases;
+    args.nleases = nleases;
+    result = rb_protect(leases_wrap, (VALUE)&args, &exception);
+
+    for (i = 0; i < nleases; i++) {
+        virNetworkDHCPLeaseFree(leases[i]);
+    }
+    free(leases);
+
+    if (exception) {
+        rb_jump_tag(exception);
+    }
+
+    return result;
+}
+#endif
+
 #endif
 
 /*
@@ -450,5 +536,20 @@ void ruby_libvirt_network_init(void)
                     INT2NUM(VIR_NETWORK_UPDATE_COMMAND_DELETE));
 #endif
 
+#if HAVE_VIRNETWORKGETDHCPLEASES
+    rb_define_method(c_network, "dhcp_leases",
+                     libvirt_network_get_dhcp_leases, -1);
+#endif
+
+#if HAVE_CONST_VIR_IP_ADDR_TYPE_IPV4
+    rb_define_const(c_network, "IP_ADDR_TYPE_IPV4",
+                    INT2NUM(VIR_IP_ADDR_TYPE_IPV4));
+#endif
+
+#if HAVE_CONST_VIR_IP_ADDR_TYPE_IPV6
+    rb_define_const(c_network, "IP_ADDR_TYPE_IPV6",
+                    INT2NUM(VIR_IP_ADDR_TYPE_IPV6));
+#endif
+
 #endif
 }
