@@ -2,7 +2,7 @@
  * storage.c: virStoragePool and virStorageVolume methods
  *
  * Copyright (C) 2007,2010 Red Hat Inc.
- * Copyright (C) 2013 Chris Lalancette <clalancette@gmail.com>
+ * Copyright (C) 2013-2016 Chris Lalancette <clalancette@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -64,7 +64,7 @@ VALUE pool_new(virStoragePoolPtr p, VALUE conn)
  * call-seq:
  *   vol.pool -> Libvirt::StoragePool
  *
- * Call virStoragePoolLookupByVolume[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolLookupByVolume]
+ * Call virStoragePoolLookupByVolume[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolLookupByVolume]
  * to retrieve the storage pool for this volume.
  */
 static VALUE libvirt_storage_vol_pool(VALUE v)
@@ -83,7 +83,7 @@ static VALUE libvirt_storage_vol_pool(VALUE v)
  * call-seq:
  *   pool.build(flags=0) -> nil
  *
- * Call virStoragePoolBuild[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolBuild]
+ * Call virStoragePoolBuild[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolBuild]
  * to build this storage pool.
  */
 static VALUE libvirt_storage_pool_build(int argc, VALUE *argv, VALUE p)
@@ -102,7 +102,7 @@ static VALUE libvirt_storage_pool_build(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.undefine -> nil
  *
- * Call virStoragePoolUndefine[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolUndefine]
+ * Call virStoragePoolUndefine[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolUndefine]
  * to undefine this storage pool.
  */
 static VALUE libvirt_storage_pool_undefine(VALUE p)
@@ -116,7 +116,7 @@ static VALUE libvirt_storage_pool_undefine(VALUE p)
  * call-seq:
  *   pool.create(flags=0) -> nil
  *
- * Call virStoragePoolCreate[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolCreate]
+ * Call virStoragePoolCreate[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolCreate]
  * to start this storage pool.
  */
 static VALUE libvirt_storage_pool_create(int argc, VALUE *argv, VALUE p)
@@ -135,7 +135,7 @@ static VALUE libvirt_storage_pool_create(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.destroy -> nil
  *
- * Call virStoragePoolDestroy[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolDestroy]
+ * Call virStoragePoolDestroy[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolDestroy]
  * to shutdown this storage pool.
  */
 static VALUE libvirt_storage_pool_destroy(VALUE p)
@@ -149,7 +149,7 @@ static VALUE libvirt_storage_pool_destroy(VALUE p)
  * call-seq:
  *   pool.delete(flags=0) -> nil
  *
- * Call virStoragePoolDelete[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolDelete]
+ * Call virStoragePoolDelete[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolDelete]
  * to delete the data corresponding to this data pool.  This is a destructive
  * operation.
  */
@@ -169,7 +169,7 @@ static VALUE libvirt_storage_pool_delete(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.refresh(flags=0) -> nil
  *
- * Call virStoragePoolRefresh[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolRefresh]
+ * Call virStoragePoolRefresh[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolRefresh]
  * to refresh the list of volumes in this storage pool.
  */
 static VALUE libvirt_storage_pool_refresh(int argc, VALUE *argv, VALUE p)
@@ -186,9 +186,9 @@ static VALUE libvirt_storage_pool_refresh(int argc, VALUE *argv, VALUE p)
 
 /*
  * call-seq:
- *   pool.name -> string
+ *   pool.name -> String
  *
- * Call virStoragePoolGetName[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolGetName]
+ * Call virStoragePoolGetName[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetName]
  * to retrieve the name of this storage pool.
  */
 static VALUE libvirt_storage_pool_name(VALUE p)
@@ -200,9 +200,9 @@ static VALUE libvirt_storage_pool_name(VALUE p)
 
 /*
  * call-seq:
- *   pool.uuid -> string
+ *   pool.uuid -> String
  *
- * Call virStoragePoolGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolGetUUIDString]
+ * Call virStoragePoolGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetUUIDString]
  * to retrieve the UUID of this storage pool.
  */
 static VALUE libvirt_storage_pool_uuid(VALUE p)
@@ -215,7 +215,7 @@ static VALUE libvirt_storage_pool_uuid(VALUE p)
  * call-seq:
  *   pool.info -> Libvirt::StoragePoolInfo
  *
- * Call virStoragePoolGetInfo[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolGetInfo]
+ * Call virStoragePoolGetInfo[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetInfo]
  * to retrieve information about this storage pool.
  */
 static VALUE libvirt_storage_pool_info(VALUE p)
@@ -240,9 +240,9 @@ static VALUE libvirt_storage_pool_info(VALUE p)
 
 /*
  * call-seq:
- *   pool.xml_desc(flags=0) -> string
+ *   pool.xml_desc(flags=0) -> String
  *
- * Call virStoragePoolGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolGetXMLDesc]
+ * Call virStoragePoolGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetXMLDesc]
  * to retrieve the XML for this storage pool.
  */
 static VALUE libvirt_storage_pool_xml_desc(int argc, VALUE *argv, VALUE p)
@@ -261,7 +261,7 @@ static VALUE libvirt_storage_pool_xml_desc(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.autostart? -> [true|false]
  *
- * Call virStoragePoolGetAutostart[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolGetAutostart]
+ * Call virStoragePoolGetAutostart[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetAutostart]
  * to determine whether this storage pool will autostart when libvirtd starts.
  */
 static VALUE libvirt_storage_pool_autostart(VALUE p)
@@ -280,7 +280,7 @@ static VALUE libvirt_storage_pool_autostart(VALUE p)
  * call-seq:
  *   pool.autostart = [true|false]
  *
- * Call virStoragePoolSetAutostart[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolSetAutostart]
+ * Call virStoragePoolSetAutostart[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolSetAutostart]
  * to make this storage pool start when libvirtd starts.
  */
 static VALUE libvirt_storage_pool_autostart_equal(VALUE p, VALUE autostart)
@@ -297,9 +297,9 @@ static VALUE libvirt_storage_pool_autostart_equal(VALUE p, VALUE autostart)
 
 /*
  * call-seq:
- *   pool.num_of_volumes -> fixnum
+ *   pool.num_of_volumes -> Fixnum
  *
- * Call virStoragePoolNumOfVolumes[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolNumOfVolumes]
+ * Call virStoragePoolNumOfVolumes[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolNumOfVolumes]
  * to retrieve the number of volumes in this storage pool.
  */
 static VALUE libvirt_storage_pool_num_of_volumes(VALUE p)
@@ -318,7 +318,7 @@ static VALUE libvirt_storage_pool_num_of_volumes(VALUE p)
  * call-seq:
  *   pool.list_volumes -> list
  *
- * Call virStoragePoolListVolumes[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolListVolumes]
+ * Call virStoragePoolListVolumes[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolListVolumes]
  * to retrieve a list of volume names in this storage pools.
  */
 static VALUE libvirt_storage_pool_list_volumes(VALUE p)
@@ -340,14 +340,14 @@ static VALUE libvirt_storage_pool_list_volumes(VALUE p)
                                 "virStoragePoolListVolumes",
                                 ruby_libvirt_connect_get(p));
 
-    return ruby_libvirt_generate_list(num, names);
+    return ruby_libvirt_generate_list(r, names);
 }
 
 /*
  * call-seq:
  *   pool.free -> nil
  *
- * Call virStoragePoolFree[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolFree]
+ * Call virStoragePoolFree[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolFree]
  * to free this storage pool object.  After this call the storage pool object
  * is no longer valid.
  */
@@ -378,7 +378,7 @@ static VALUE vol_new(virStorageVolPtr v, VALUE conn)
  * call-seq:
  *   pool.lookup_volume_by_name(name) -> Libvirt::StorageVol
  *
- * Call virStorageVolLookupByName[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolLookupByName]
+ * Call virStorageVolLookupByName[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByName]
  * to retrieve a storage volume object by name.
  */
 static VALUE libvirt_storage_pool_lookup_vol_by_name(VALUE p, VALUE name)
@@ -397,7 +397,7 @@ static VALUE libvirt_storage_pool_lookup_vol_by_name(VALUE p, VALUE name)
  * call-seq:
  *   pool.lookup_volume_by_key(key) -> Libvirt::StorageVol
  *
- * Call virStorageVolLookupByKey[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolLookupByKey]
+ * Call virStorageVolLookupByKey[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByKey]
  * to retrieve a storage volume object by key.
  */
 static VALUE libvirt_storage_pool_lookup_vol_by_key(VALUE p, VALUE key)
@@ -418,7 +418,7 @@ static VALUE libvirt_storage_pool_lookup_vol_by_key(VALUE p, VALUE key)
  * call-seq:
  *   pool.lookup_volume_by_path(path) -> Libvirt::StorageVol
  *
- * Call virStorageVolLookupByPath[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolLookupByPath]
+ * Call virStorageVolLookupByPath[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByPath]
  * to retrieve a storage volume object by path.
  */
 static VALUE libvirt_storage_pool_lookup_vol_by_path(VALUE p, VALUE path)
@@ -438,9 +438,9 @@ static VALUE libvirt_storage_pool_lookup_vol_by_path(VALUE p, VALUE path)
 #if HAVE_VIRSTORAGEPOOLLISTALLVOLUMES
 /*
  * call-seq:
- *   pool.list_all_volumes(flags=0) -> array
+ *   pool.list_all_volumes(flags=0) -> Array
  *
- * Call virStoragePoolListAllVolumes[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolListAllVolumes]
+ * Call virStoragePoolListAllVolumes[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolListAllVolumes]
  * to get an array of volume objects for all volumes.
  */
 static VALUE libvirt_storage_pool_list_all_volumes(int argc, VALUE *argv,
@@ -455,9 +455,9 @@ static VALUE libvirt_storage_pool_list_all_volumes(int argc, VALUE *argv,
 
 /*
  * call-seq:
- *   vol.name -> string
+ *   vol.name -> String
  *
- * Call virStorageVolGetName[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolGetName]
+ * Call virStorageVolGetName[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetName]
  * to retrieve the name of this storage volume.
  */
 static VALUE libvirt_storage_vol_name(VALUE v)
@@ -469,9 +469,9 @@ static VALUE libvirt_storage_vol_name(VALUE v)
 
 /*
  * call-seq:
- *   vol.key -> string
+ *   vol.key -> String
  *
- * Call virStorageVolGetKey[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolGetKey]
+ * Call virStorageVolGetKey[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetKey]
  * to retrieve the key for this storage volume.
  */
 static VALUE libvirt_storage_vol_key(VALUE v)
@@ -485,7 +485,7 @@ static VALUE libvirt_storage_vol_key(VALUE v)
  * call-seq:
  *   pool.create_volume_xml(xml, flags=0) -> Libvirt::StorageVol
  *
- * Call virStorageVolCreateXML[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolCreateXML]
+ * Call virStorageVolCreateXML[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolCreateXML]
  * to create a new storage volume from xml.
  */
 static VALUE libvirt_storage_pool_create_volume_xml(int argc, VALUE *argv,
@@ -498,7 +498,7 @@ static VALUE libvirt_storage_pool_create_volume_xml(int argc, VALUE *argv,
 
     vol = virStorageVolCreateXML(pool_get(p), StringValueCStr(xml),
                                  ruby_libvirt_value_to_uint(flags));
-    ruby_libvirt_raise_error_if(vol == NULL, e_Error, "virNetworkCreateXML",
+    ruby_libvirt_raise_error_if(vol == NULL, e_Error, "virStorageVolCreateXML",
                                 ruby_libvirt_connect_get(p));
 
     return vol_new(vol, ruby_libvirt_conn_attr(p));
@@ -509,7 +509,7 @@ static VALUE libvirt_storage_pool_create_volume_xml(int argc, VALUE *argv,
  * call-seq:
  *   pool.create_volume_xml_from(xml, clonevol, flags=0) -> Libvirt::StorageVol
  *
- * Call virStorageVolCreateXMLFrom[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolCreateXMLFrom]
+ * Call virStorageVolCreateXMLFrom[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolCreateXMLFrom]
  * to clone a volume from an existing volume with the properties specified in
  * xml.
  */
@@ -525,7 +525,7 @@ static VALUE libvirt_storage_pool_create_volume_xml_from(int argc, VALUE *argv,
                                      vol_get(cloneval),
                                      ruby_libvirt_value_to_uint(flags));
     ruby_libvirt_raise_error_if(vol == NULL, e_Error,
-                                "virNetworkCreateXMLFrom",
+                                "virStorageVolCreateXMLFrom",
                                 ruby_libvirt_connect_get(p));
 
     return vol_new(vol, ruby_libvirt_conn_attr(p));
@@ -537,7 +537,7 @@ static VALUE libvirt_storage_pool_create_volume_xml_from(int argc, VALUE *argv,
  * call-seq:
  *   pool.active? -> [true|false]
  *
- * Call virStoragePoolIsActive[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolIsActive]
+ * Call virStoragePoolIsActive[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolIsActive]
  * to determine if this storage pool is active.
  */
 static VALUE libvirt_storage_pool_active_p(VALUE p)
@@ -553,7 +553,7 @@ static VALUE libvirt_storage_pool_active_p(VALUE p)
  * call-seq:
  *   pool.persistent? -> [true|false]
  *
- * Call virStoragePoolIsPersistent[http://www.libvirt.org/html/libvirt-libvirt.html#virStoragePoolIsPersistent]
+ * Call virStoragePoolIsPersistent[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolIsPersistent]
  * to determine if this storage pool is persistent.
  */
 static VALUE libvirt_storage_pool_persistent_p(VALUE p)
@@ -568,7 +568,7 @@ static VALUE libvirt_storage_pool_persistent_p(VALUE p)
  * call-seq:
  *   vol.delete(flags=0) -> nil
  *
- * Call virStorageVolDelete[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolDelete]
+ * Call virStorageVolDelete[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolDelete]
  * to delete this volume.  This is a destructive operation.
  */
 static VALUE libvirt_storage_vol_delete(int argc, VALUE *argv, VALUE v)
@@ -588,7 +588,7 @@ static VALUE libvirt_storage_vol_delete(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.wipe(flags=0) -> nil
  *
- * Call virStorageVolWipe[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolWipe]
+ * Call virStorageVolWipe[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolWipe]
  * to wipe the data from this storage volume.  This is a destructive operation.
  */
 static VALUE libvirt_storage_vol_wipe(int argc, VALUE *argv, VALUE v)
@@ -608,7 +608,7 @@ static VALUE libvirt_storage_vol_wipe(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.info -> Libvirt::StorageVolInfo
  *
- * Call virStorageVolGetInfo[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolGetInfo]
+ * Call virStorageVolGetInfo[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetInfo]
  * to retrieve information about this storage volume.
  */
 static VALUE libvirt_storage_vol_info(VALUE v)
@@ -631,9 +631,9 @@ static VALUE libvirt_storage_vol_info(VALUE v)
 
 /*
  * call-seq:
- *   vol.xml_desc(flags=0) -> string
+ *   vol.xml_desc(flags=0) -> String
  *
- * Call virStorageVolGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolGetXMLDesc]
+ * Call virStorageVolGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetXMLDesc]
  * to retrieve the xml for this storage volume.
  */
 static VALUE libvirt_storage_vol_xml_desc(int argc, VALUE *argv, VALUE v)
@@ -650,9 +650,9 @@ static VALUE libvirt_storage_vol_xml_desc(int argc, VALUE *argv, VALUE v)
 
 /*
  * call-seq:
- *   vol.path -> string
+ *   vol.path -> String
  *
- * Call virStorageVolGetPath[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolGetPath]
+ * Call virStorageVolGetPath[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetPath]
  * to retrieve the path for this storage volume.
  */
 static VALUE libvirt_storage_vol_path(VALUE v)
@@ -666,7 +666,7 @@ static VALUE libvirt_storage_vol_path(VALUE v)
  * call-seq:
  *   vol.free -> nil
  *
- * Call virStorageVolFree[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolFree]
+ * Call virStorageVolFree[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolFree]
  * to free the storage volume object.  After this call the storage volume object
  * is no longer valid.
  */
@@ -681,7 +681,7 @@ static VALUE libvirt_storage_vol_free(VALUE v)
  * call-seq:
  *   vol.download(stream, offset, length, flags=0) -> nil
  *
- * Call virStorageVolDownload[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolDownload]
+ * Call virStorageVolDownload[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolDownload]
  * to download the content of a volume as a stream.
  */
 static VALUE libvirt_storage_vol_download(int argc, VALUE *argv, VALUE v)
@@ -701,7 +701,7 @@ static VALUE libvirt_storage_vol_download(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.upload(stream, offset, length, flags=0) -> nil
  *
- * Call virStorageVolUpload[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolUpload]
+ * Call virStorageVolUpload[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolUpload]
  * to upload new content to a volume from a stream.
  */
 static VALUE libvirt_storage_vol_upload(int argc, VALUE *argv, VALUE v)
@@ -723,7 +723,7 @@ static VALUE libvirt_storage_vol_upload(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.wipe_pattern(alg, flags=0) -> nil
  *
- * Call virStorageVolWipePattern[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolWipePattern]
+ * Call virStorageVolWipePattern[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolWipePattern]
  * to wipe the data from this storage volume.  This is a destructive operation.
  */
 static VALUE libvirt_storage_vol_wipe_pattern(int argc, VALUE *argv, VALUE v)
@@ -744,7 +744,7 @@ static VALUE libvirt_storage_vol_wipe_pattern(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.resize(capacity, flags=0) -> nil
  *
- * Call virStorageVolResize[http://www.libvirt.org/html/libvirt-libvirt.html#virStorageVolResize]
+ * Call virStorageVolResize[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolResize]
  * to resize the associated storage volume.
  */
 static VALUE libvirt_storage_vol_resize(int argc, VALUE *argv, VALUE v)
@@ -815,6 +815,27 @@ void ruby_libvirt_storage_init(void)
     rb_define_const(c_storage_pool, "CREATE_PREALLOC_METADATA",
                     INT2NUM(VIR_STORAGE_VOL_CREATE_PREALLOC_METADATA));
 #endif
+#if HAVE_CONST_VIR_STORAGE_VOL_CREATE_REFLINK
+    rb_define_const(c_storage_pool, "CREATE_REFLINK",
+                    INT2NUM(VIR_STORAGE_VOL_CREATE_REFLINK));
+#endif
+
+#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_NORMAL
+    rb_define_const(c_storage_pool, "CREATE_NORMAL",
+                    INT2NUM(VIR_STORAGE_POOL_CREATE_NORMAL));
+#endif
+#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_WITH_BUILD
+    rb_define_const(c_storage_pool, "CREATE_WITH_BUILD",
+                    INT2NUM(VIR_STORAGE_POOL_CREATE_WITH_BUILD));
+#endif
+#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE
+    rb_define_const(c_storage_pool, "CREATE_WITH_BUILD_OVERWRITE",
+                    INT2NUM(VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE));
+#endif
+#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE
+    rb_define_const(c_storage_pool, "CREATE_WITH_BUILD_NO_OVERWRITE",
+                    INT2NUM(VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE));
+#endif
 
     /* Creating/destroying pools */
     rb_define_method(c_storage_pool, "build", libvirt_storage_pool_build, -1);
@@ -913,12 +934,19 @@ void ruby_libvirt_storage_init(void)
 #if HAVE_CONST_VIR_STORAGE_VOL_NETWORK
     rb_define_const(c_storage_vol, "NETWORK", INT2NUM(VIR_STORAGE_VOL_NETWORK));
 #endif
+#if HAVE_CONST_VIR_STORAGE_VOL_NETDIR
+    rb_define_const(c_storage_vol, "NETDIR", INT2NUM(VIR_STORAGE_VOL_NETDIR));
+#endif
 
     /* virStorageVolDeleteFlags */
     rb_define_const(c_storage_vol, "DELETE_NORMAL",
                     INT2NUM(VIR_STORAGE_VOL_DELETE_NORMAL));
     rb_define_const(c_storage_vol, "DELETE_ZEROED",
                     INT2NUM(VIR_STORAGE_VOL_DELETE_ZEROED));
+#if HAVE_CONST_VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS
+    rb_define_const(c_storage_vol, "DELETE_WITH_SNAPSHOTS",
+                    INT2NUM(VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS));
+#endif
 
     rb_define_method(c_storage_vol, "pool", libvirt_storage_vol_pool, 0);
     rb_define_method(c_storage_vol, "name", libvirt_storage_vol_name, 0);
